@@ -2,7 +2,7 @@ use crate::{cargo::Lockfile, sonar};
 use eyre::{Context, Result};
 use rustsec::{Report, Vulnerability};
 use std::{fs::File, path::PathBuf};
-use tracing::{error, info};
+use tracing::info;
 
 const AUDIT_ENGINE: &str = "audit";
 
@@ -22,9 +22,8 @@ impl<'lock> Audit<'lock> {
         }
     }
 
-    // FIXME: reporting on 'Cargo.toml' is a bad idea because the vulnerability might exist on a nested dependency
-    // it might be possible to use 'Cargo.lock' instead (or use 'cargo-deny' to obtain a graph of dependency and find the root dependency)
-    fn to_issue(&self, vulnerability: &Vulnerability) -> sonar::Issue {
+    #[allow(clippy::needless_pass_by_value)]
+    fn to_issue(&self, vulnerability: Vulnerability) -> sonar::Issue {
         let advisory = &vulnerability.advisory;
         let rule_id = format!("{}::{}", AUDIT_ENGINE, advisory.id);
         let message = format!(
@@ -32,19 +31,7 @@ impl<'lock> Audit<'lock> {
             advisory.title, advisory.package, advisory.id
         );
         let file_path = self.lockfile.lockfile_path.to_string_lossy().to_string();
-        let dependency = self.lockfile.dependencies.get(advisory.package.as_str());
-        let text_range = dependency
-            .map(|ranges| &ranges.range)
-            .map(sonar::TextRange::clone)
-            .unwrap_or_else(|| {
-                error!("failed to find a corresponding text range for this vulnerability. This is probably a bug in `cargo-sonar`, if you can please report an issue at https://gitlab.com/woshilapin/cargo-sonar/-/issues, we'd be happy to try and fix it.");
-                sonar::TextRange {
-                    start_line: 1,
-                    end_line: 1,
-                    start_column: 0,
-                    end_column: 1,
-                }
-            });
+        let text_range = self.lockfile.dependency_range(advisory.package.as_str());
         let primary_location = sonar::Location {
             message,
             file_path,
@@ -64,7 +51,7 @@ impl<'lock> Audit<'lock> {
         report
             .vulnerabilities
             .list
-            .iter()
+            .into_iter()
             .map(|vulnerability| self.to_issue(vulnerability))
             .collect()
     }
