@@ -29,13 +29,11 @@ pub enum Error {
 
 impl From<&DiagnosticLevel> for sonar::Severity {
     fn from(level: &DiagnosticLevel) -> Self {
-        use DiagnosticLevel::*;
         match level {
-            Ice => sonar::Severity::Blocker,
-            Error => sonar::Severity::Critical,
-            Warning => sonar::Severity::Major,
-            FailureNote => sonar::Severity::Minor,
-            Note | Help => sonar::Severity::Info,
+            DiagnosticLevel::Ice => sonar::Severity::Blocker,
+            DiagnosticLevel::Error => sonar::Severity::Critical,
+            DiagnosticLevel::Warning => sonar::Severity::Major,
+            DiagnosticLevel::FailureNote => sonar::Severity::Minor,
             _ => sonar::Severity::Info,
         }
     }
@@ -46,7 +44,7 @@ impl From<&DiagnosticSpan> for sonar::TextRange {
         Self {
             start_line: span.line_start,
             end_line: span.line_end,
-            // FIXME: we should actually check is spans have a column bound on
+            // FIXME: we should actually check if spans have a column bound on
             // an line end and remove 1 if this is the case.
             // clippy does consider the end-of-line character
             // but sonar-scanner does not and check for validity
@@ -59,14 +57,11 @@ impl From<&DiagnosticSpan> for sonar::TextRange {
 impl TryFrom<Message> for sonar::Issue {
     type Error = Error;
     fn try_from(message: Message) -> Result<Self, Self::Error> {
-        use Message::*;
-        if let CompilerMessage(message) = message {
-            let rule_id = message
-                .message
-                .code
-                .as_ref()
-                .map(|diagnostic_code| diagnostic_code.code.clone())
-                .unwrap_or_else(|| String::from("clippy"));
+        if let Message::CompilerMessage(message) = message {
+            let rule_id = message.message.code.as_ref().map_or_else(
+                || String::from("clippy"),
+                |diagnostic_code| diagnostic_code.code.clone(),
+            );
             let severity = sonar::Severity::from(&message.message.level);
             let r#type = sonar::IssueType::CodeSmell;
             let (primary_location, secondary_locations) = match message.message.spans.len() {
@@ -79,7 +74,7 @@ impl TryFrom<Message> for sonar::Issue {
                         text_range: sonar::TextRange::from(span),
                     };
                     let secondary_locations = (1..n)
-                        .flat_map(|idx| message.message.spans.get(idx))
+                        .filter_map(|idx| message.message.spans.get(idx))
                         .map(|span| sonar::Location {
                             message: message.message.message.clone(),
                             file_path: span.file_name.clone(),
@@ -100,13 +95,13 @@ impl TryFrom<Message> for sonar::Issue {
             Ok(issue)
         } else {
             let kind = match message {
-                CompilerArtifact(_) => "compiler-artifact",
-                CompilerMessage(_) => {
+                Message::CompilerArtifact(_) => "compiler-artifact",
+                Message::CompilerMessage(_) => {
                     unreachable!("'CompilerMessage' has already been parsed above")
                 }
-                BuildScriptExecuted(_) => "build-script-executed",
-                BuildFinished(_) => "build-finished",
-                TextLine(_) => "text-line",
+                Message::BuildScriptExecuted(_) => "build-script-executed",
+                Message::BuildFinished(_) => "build-finished",
+                Message::TextLine(_) => "text-line",
                 _ => "unknown",
             };
             Err(Error::InvalidMessage(kind))
