@@ -6,7 +6,7 @@ use std::{
     io::{BufRead as _, BufReader},
     path::PathBuf,
 };
-use tracing::{error, info};
+use tracing::info;
 
 const DENY_ENGINE: &str = "deny";
 
@@ -60,7 +60,7 @@ impl<'lock> Deny<'lock> {
             lockfile,
         }
     }
-    fn to_issue(&self, deny_report: &DenyReport) -> Option<sonar::Issue> {
+    fn to_issue(&self, deny_report: &DenyReport) -> sonar::Issue {
         match deny_report {
             DenyReport::Advisory { advisory } => {
                 let rule_id = format!("{}::{}", DENY_ENGINE, advisory.id);
@@ -69,34 +69,21 @@ impl<'lock> Deny<'lock> {
                     advisory.title, advisory.package, advisory.id
                 );
                 let file_path = self.lockfile.lockfile_path.to_string_lossy().to_string();
-                let dependency = self.lockfile.dependencies.get(advisory.package.as_str());
-                let text_range = dependency
-                    .map(|ranges| &ranges.range)
-                    .map(sonar::TextRange::clone)
-                    .unwrap_or_else(|| {
-                        error!("failed to find a corresponding text range for the advisory related to '{}'. This is probably a bug in `cargo-sonar`, if you can please report an issue at https://gitlab.com/woshilapin/cargo-sonar/-/issues, we'd be happy to try and fix it.", advisory.package);
-                        sonar::TextRange {
-                            start_line: 1,
-                            end_line: 1,
-                            start_column: 0,
-                            end_column: 1,
-                        }
-                    });
+                let text_range = self.lockfile.dependency_range(advisory.package.as_str());
                 let primary_location = sonar::Location {
                     message,
                     file_path,
                     text_range,
                 };
                 let secondary_locations = Vec::new();
-                let issue = sonar::Issue {
+                sonar::Issue {
                     engine_id: DENY_ENGINE.to_string(),
                     rule_id,
                     severity: sonar::Severity::Major,
                     r#type: sonar::IssueType::Vulnerability,
                     primary_location,
                     secondary_locations,
-                };
-                Some(issue)
+                }
             }
             DenyReport::License {
                 code,
@@ -105,21 +92,9 @@ impl<'lock> Deny<'lock> {
                 labels,
             } => {
                 let graph_node = graphs.get(0).unwrap();
-                let dependency = self.lockfile.dependencies.get(graph_node.name.as_str());
                 let file_path = self.lockfile.lockfile_path.to_string_lossy().to_string();
-                let text_range = dependency
-                    .map(|ranges| &ranges.range)
-                    .map(sonar::TextRange::clone)
-                    .unwrap_or_else(|| {
-                        error!("failed to find a corresponding text range for this license warning related to '{}'. This is probably a bug in `cargo-sonar`, if you can please report an issue at https://gitlab.com/woshilapin/cargo-sonar/-/issues, we'd be happy to try and fix it.", graph_node.name);
-                        sonar::TextRange {
-                            start_line: 1,
-                            end_line: 1,
-                            start_column: 0,
-                            end_column: 1,
-                        }
-                    });
-                let message = labels.iter().fold(message.to_owned(), |message, label| {
+                let text_range = self.lockfile.dependency_range(graph_node.name.as_str());
+                let message = labels.iter().fold(message.clone(), |message, label| {
                     format!("{}.\n`{}` {}", message, label.span, label.message)
                 });
                 let primary_location = sonar::Location {
@@ -128,15 +103,14 @@ impl<'lock> Deny<'lock> {
                     text_range,
                 };
                 let secondary_locations = Vec::new();
-                let issue = sonar::Issue {
+                sonar::Issue {
                     engine_id: DENY_ENGINE.to_string(),
                     rule_id: format!("{}::{}", DENY_ENGINE, code),
                     severity: sonar::Severity::Info,
                     r#type: sonar::IssueType::CodeSmell,
                     primary_location,
                     secondary_locations,
-                };
-                Some(issue)
+                }
             }
         }
     }
@@ -157,13 +131,13 @@ impl std::convert::TryInto<sonar::Report> for Deny<'_> {
             .lines()
             .flatten()
             .flat_map(|line| serde_json::from_str::<serde_json::Value>(&line))
-            .flat_map(|value| value.get("fields").map(ToString::to_string))
+            .filter_map(|value| value.get("fields").map(ToString::to_string))
             .map(|s| {
                 serde_json::from_str::<DenyReport>(&s)
                     .with_context(|| format!("failed to deserialize '{}'", s))
             })
             .skip_error_and_debug()
-            .flat_map(|diagnostic| self.to_issue(&diagnostic))
+            .map(|diagnostic| self.to_issue(&diagnostic))
             .collect();
         info!("{} sonar issues created", issues.len());
         Ok(issues)
