@@ -78,6 +78,6 @@ impl IntoIterator for Report {
 
 impl Extend<Issue> for Report {
     fn extend<T: IntoIterator<Item = Issue>>(&mut self, iter: T) {
-        self.issues.extend(iter)
+        self.issues.extend(iter);
     }
 }
